@@ -23,12 +23,14 @@ except ImportError as _excp:
     else:
         raise
 
+import traceback
 import numpy as np
 import unittest
 import warnings
 from matplotlib import pyplot
 from matplotlib.cbook import MatplotlibDeprecationWarning
 import yaml
+import traceback
 
 from omfit_classes.omfit_github import (
     set_gh_status,
@@ -105,10 +107,9 @@ auto_comment_marker = (
     '<!--This comment was automatically generated by OMFIT and was not posted directly by a human. ' 'A2ZZJfxk2910x2AZZf -->'
 )
 
-# auto_test_mode is a flag that indicates that the tests are being run automatically, such as by morti, and so
-# behavior should be modified.
+# auto_test_mode is a flag that indicates that the tests are being run automatically, such as by morti, and so behavior should be modified.
 try:
-    auto_test_mode = bool(is_server('localhost', 'morti'))
+    auto_test_mode = bool(is_server('localhost', 'morti')) and repo is not None
 except KeyError:
     auto_test_mode = False
 
@@ -224,6 +225,8 @@ class setup_warnings(object):
             warnings.filterwarnings('ignore', category=FutureWarning, message='The Panel class is removed*')
             warnings.filterwarnings('ignore', category=PendingDeprecationWarning)
             warnings.filterwarnings('ignore', category=UserWarning, message="Warning: converting a masked element to nan.")
+            # psycopg2
+            warnings.filterwarnings('ignore', message='The psycopg2 wheel package will be renamed from release 2.8*')
 
         if level <= 1:
             # Divide by 0
@@ -644,7 +647,7 @@ def run_test_outside_framework(test_script, catch_exp_reports=True):
         End of output
     """
 
-    print('Running {} in a separate process (no framework), please stand by.'.format(os.path.basename(test_script)))
+    print('Running {} in a separate process (no framework)'.format(os.path.basename(test_script)))
     result = subprocess.Popen(['python3', test_script], stdout=subprocess.PIPE, stderr=subprocess.STDOUT, universal_newlines=True)
     result.wait()
     return_code = result.returncode
@@ -920,7 +923,7 @@ class OMFITtest(unittest.TestCase):
     def __init__(self, *args, **kwargs):
         import astropy.table
 
-        super(OMFITtest, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
         # Define sample experiment information: override later if needed
         experiment = dict(device='DIII-D', shot=154749, shots=[154749, 154754], time=2500.0, times=[2500.0, 3000.0])
@@ -1969,8 +1972,7 @@ def run_test_series(exit_at_end=False, post_gh_comment=False, post_gh_status=Fal
     tests_since_last_commit_check = 0
     for test in test_plan['tests']:
 
-        # Check github for a newer commit and abort if it's newer than the current ones
-        # if the option is enabled.
+        # Check github for a newer commit and abort if it's newer than the current ones if the option is enabled.
         if test_plan.get('newer_commit_abort', False) and (
             (time.time() - last_commit_check_time > test_plan.get('newer_commit_check_period', 120))
             or (tests_since_last_commit_check > test_plan.get('newer_commit_test_num_period', 10))
@@ -2050,8 +2052,7 @@ def run_test_series(exit_at_end=False, post_gh_comment=False, post_gh_status=Fal
                     t_desc = 'Timeout:' + t_desc
                 set_gh_status(state=False, context=t_context, description=t_desc)
         else:
-            # Disabling the alarm should happen before anything else as to not risk moving over
-            # the timeout threshold.
+            # Disabling the alarm should happen before anything else as to not risk moving over the timeout threshold.
             signal.alarm(0)
             if False:
                 mod_list = sorted(list(set([mod['ID'] for mod in list(OMFIT.moduleDict().values())])))
@@ -2086,7 +2087,7 @@ def run_test_series(exit_at_end=False, post_gh_comment=False, post_gh_status=Fal
     # update test plan with results
     class YAMLDumper(yaml.Dumper):
         def increase_indent(self, flow=False, indentless=False):
-            return super(YAMLDumper, self).increase_indent(flow, False)
+            return super().increase_indent(flow, False)
 
     if test_plan_file:
         test_plan_yaml_update = yaml.dump(test_plan, Dumper=YAMLDumper, default_flow_style=False)
